@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,9 +30,7 @@
 
 using namespace MailCommon;
 
-FilterActionMissingSoundUrlDialog::FilterActionMissingSoundUrlDialog(const QString &filtername,
-        const QString &argStr,
-        QWidget *parent)
+FilterActionMissingSoundUrlDialog::FilterActionMissingSoundUrlDialog(const QString &filtername, const QString &argStr, QWidget *parent)
     : QDialog(parent)
 {
     setModal(true);
@@ -92,4 +90,3 @@ void FilterActionMissingSoundUrlDialog::writeConfig()
     KConfigGroup group(KSharedConfig::openConfig(), "FilterActionMissingSoundUrlDialog");
     group.writeEntry("Size", size());
 }
-
