@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -58,16 +58,18 @@ public:
     {
     }
 
-    QListWidget *mListAccount;
-    QPushButton *mUpButton;
-    QPushButton *mDownButton;
-    QCheckBox *mEnableAccountOrder;
+    QListWidget *mListAccount = nullptr;
+    QPushButton *mUpButton = nullptr;
+    QPushButton *mDownButton = nullptr;
+    QCheckBox *mEnableAccountOrder = nullptr;
+    MailCommon::MailCommonSettings *mSettings = nullptr;
 };
 
-AccountConfigOrderDialog::AccountConfigOrderDialog(QWidget *parent)
+AccountConfigOrderDialog::AccountConfigOrderDialog(MailCommon::MailCommonSettings *settings, QWidget *parent)
     : QDialog(parent)
     , d(new MailCommon::AccountConfigOrderDialogPrivate)
 {
+    d->mSettings = settings;
     setWindowTitle(i18n("Edit Accounts Order"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
@@ -186,7 +188,7 @@ void AccountConfigOrderDialog::slotEnableControls()
 
 void AccountConfigOrderDialog::init()
 {
-    const QStringList listOrderAccount = MailCommon::MailCommonSettings::self()->order();
+    const QStringList listOrderAccount = d->mSettings->order();
     QStringList instanceList;
 
     QMap<QString, InstanceStruct> mapInstance;
@@ -194,9 +196,9 @@ void AccountConfigOrderDialog::init()
     for (const Akonadi::AgentInstance &instance : lstInstances) {
         const QStringList capabilities(instance.type().capabilities());
         if (instance.type().mimeTypes().contains(KMime::Message::mimeType())) {
-            if (capabilities.contains(QStringLiteral("Resource"))
-                && !capabilities.contains(QStringLiteral("Virtual"))
-                && !capabilities.contains(QStringLiteral("MailTransport"))) {
+            if (capabilities.contains(QLatin1String("Resource"))
+                && !capabilities.contains(QLatin1String("Virtual"))
+                && !capabilities.contains(QLatin1String("MailTransport"))) {
                 const QString identifier = instance.identifier();
                 if (!identifier.contains(POP3_RESOURCE_IDENTIFIER)) {
                     instanceList << instance.identifier();
@@ -204,11 +206,11 @@ void AccountConfigOrderDialog::init()
                     instanceStruct.name = instance.name();
                     if (PimCommon::Util::isImapResource(identifier)) {
                         instanceStruct.name += QLatin1String(" (IMAP)");
-                    } else if (identifier.startsWith(QStringLiteral("akonadi_maildir_resource"))) {
+                    } else if (identifier.startsWith(QLatin1String("akonadi_maildir_resource"))) {
                         instanceStruct.name += QLatin1String(" (Maildir)");
-                    } else if (identifier.startsWith(QStringLiteral("akonadi_mailbox_resource"))) {
+                    } else if (identifier.startsWith(QLatin1String("akonadi_mailbox_resource"))) {
                         instanceStruct.name += QLatin1String(" (Mailbox)");
-                    } else if (identifier.startsWith(QStringLiteral("akonadi_mixedmaildir_resource"))) {
+                    } else if (identifier.startsWith(QLatin1String("akonadi_mixedmaildir_resource"))) {
                         instanceStruct.name += QLatin1String(" (Mixedmaildir)");
                     } else {
                         qCDebug(MAILCOMMON_LOG) << " Unknown resource type " << identifier;
@@ -238,7 +240,7 @@ void AccountConfigOrderDialog::init()
             d->mListAccount->addItem(item);
         }
     }
-    const bool enabled = MailCommon::MailCommonSettings::self()->enableAccountOrder();
+    const bool enabled = d->mSettings->enableAccountOrder();
     d->mEnableAccountOrder->setChecked(enabled);
     slotEnableAccountOrder(enabled);
 }
@@ -252,15 +254,15 @@ void AccountConfigOrderDialog::slotOk()
         order << d->mListAccount->item(i)->data(AccountConfigOrderDialog::IdentifierAccount).toString();
     }
 
-    MailCommon::MailCommonSettings::self()->setOrder(order);
-    MailCommon::MailCommonSettings::self()->setEnableAccountOrder(d->mEnableAccountOrder->isChecked());
-    MailCommon::MailCommonSettings::self()->save();
+    d->mSettings->setOrder(order);
+    d->mSettings->setEnableAccountOrder(d->mEnableAccountOrder->isChecked());
+    d->mSettings->save();
     QDialog::accept();
 }
 
 void AccountConfigOrderDialog::readConfig()
 {
-    KConfigGroup accountConfigDialog(MailCommon::MailCommonSettings::self()->config(), "AccountConfigOrderDialog");
+    KConfigGroup accountConfigDialog(d->mSettings->config(), "AccountConfigOrderDialog");
     const QSize size = accountConfigDialog.readEntry("Size", QSize(600, 400));
     if (size.isValid()) {
         resize(size);
@@ -269,7 +271,7 @@ void AccountConfigOrderDialog::readConfig()
 
 void AccountConfigOrderDialog::writeConfig()
 {
-    KConfigGroup accountConfigDialog(MailCommon::MailCommonSettings::self()->config(), "AccountConfigOrderDialog");
+    KConfigGroup accountConfigDialog(d->mSettings->config(), "AccountConfigOrderDialog");
     accountConfigDialog.writeEntry("Size", size());
     accountConfigDialog.sync();
 }
