@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,17 +19,16 @@
 #define ACCOUNTCONFIGORDERDIALOG_H
 
 #include <QDialog>
-#include <KConfigGroup>
 #include "mailcommon_export.h"
 
-namespace MailCommon
-{
+namespace MailCommon {
 class AccountConfigOrderDialogPrivate;
+class MailCommonSettings;
 class MAILCOMMON_EXPORT AccountConfigOrderDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit AccountConfigOrderDialog(QWidget *parent);
+    explicit AccountConfigOrderDialog(MailCommon::MailCommonSettings *settings, QWidget *parent);
     ~AccountConfigOrderDialog();
 
 private:
