@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -53,11 +53,11 @@ public:
     {
     }
 
-    FolderTreeWidget *folderTreeWidget;
-    QPushButton *mUser1Button;
-    QPushButton *mOkButton;
-    bool mNotAllowToCreateNewFolder;
-    bool mUseGlobalSettings;
+    FolderTreeWidget *folderTreeWidget = nullptr;
+    QPushButton *mUser1Button = nullptr;
+    QPushButton *mOkButton = nullptr;
+    bool mNotAllowToCreateNewFolder = false;
+    bool mUseGlobalSettings = false;
 };
 
 FolderSelectionDialog::FolderSelectionDialog(QWidget *parent, SelectionFolderOptions options)
@@ -68,8 +68,7 @@ FolderSelectionDialog::FolderSelectionDialog(QWidget *parent, SelectionFolderOpt
 
     d->mNotAllowToCreateNewFolder = (options & FolderSelectionDialog::NotAllowToCreateNewFolder);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     d->mOkButton->setDefault(true);
     d->mOkButton->setAutoDefault(true);
@@ -131,8 +130,8 @@ FolderSelectionDialog::FolderSelectionDialog(QWidget *parent, SelectionFolderOpt
     connect(d->folderTreeWidget->folderTreeWidgetProxyModel(), &QAbstractItemModel::rowsInserted,
             this, &FolderSelectionDialog::rowsInserted);
 
-    connect(d->folderTreeWidget->folderTreeView(), SIGNAL(doubleClicked(QModelIndex)),
-            this, SLOT(slotDoubleClick(QModelIndex)));
+    connect(d->folderTreeWidget->folderTreeView(), QOverload<const QModelIndex &>::of(&QAbstractItemView::doubleClicked),
+            this, &FolderSelectionDialog::slotDoubleClick);
 
     d->mUseGlobalSettings = !(options & NotUseGlobalSettings);
     readConfig();
